LinearGradientCoords

Enum LinearGradientCoords 

pub enum LinearGradientCoords {
    Ends {
        start: Point,
        end: Point,
    },
    Angle {
        angle: Angle,
        displacement: OnPlanePos,
    },
    Direction {
        direction: RelativeDir,
        displacement: OnPlanePos,
    },
}
Describes the coordinates of a colorful linear gradient.

Variants



Ends

Defines the linear gradient by point A to point B.

Fields

start: Point
end: Point


Angle

Defines the linear gradient using an angle and a displacement from the center of the target figure.

Fields

angle: Angle
displacement: OnPlanePos


Direction

Fields

direction: RelativeDir
displacement: OnPlanePos

Implementations

Source

impl LinearGradientCoords

pub fn from_ends( start: impl Into<Point>, end: impl Into<Point>, ) -> LinearGradientCoords

Creates a LinearGradientCoords from its ends.

pub fn from_angle(angle: Angle) -> LinearGradientCoords

Creates a LinearGradientCoords from its angle.

pub fn with_displacement(&mut self, displacement: impl Into<OnPlanePos>) -> Self

Sets the displacement if self is defined by its angle, otherwise, this does nothing.