Rectangle

Struct Rectangle 

pub struct Rectangle { /* private fields */ }
A Rectangle is normally expressed as a top-left corner and a size

Examples

let rectangle = Rectangle::new((0., 5.),(10., 7.));

assert_eq!(rectangle.x(), 0.);
assert_eq!(rectangle.y(), 5.);
assert_eq!(rectangle.width(), 10.);
assert_eq!(rectangle.height(), 7.);

Implementations

Source

impl Rectangle

pub fn new(position: impl Into<Point>, size: impl Into<Size>) -> Self

Create a new rectangle with the given parameters.

pub fn x(&self) -> f64

Gets x coordiante.

pub fn set_x(&mut self, x: impl Into<f64>)

Sets x coordinate.

pub fn y(&self) -> f64

Gets y coordinate.

pub fn set_y(&mut self, y: impl Into<f64>)

Sets y coordinate.

pub fn position(&self) -> Point

Gets position as Point.

pub fn set_position(&mut self, position: impl Into<Point>)

Sets position.

pub fn width(&self) -> f64

Gets the width.

pub fn set_width(&mut self, width: impl Into<f64>)

Sets the width.

pub fn height(&self) -> f64

Gets the height.

pub fn set_height(&mut self, height: impl Into<f64>)

Sets the height.

pub fn size(&self) -> Size

Gets the size with width and height.

pub fn set_size(&mut self, width: impl Into<f64>, height: impl Into<f64>)

Sets the size with width and height.

pub fn contains(&self, point: impl Into<Point>) -> bool

Checks if this rect contains the given point.

pub fn contains_rect(&self, rect: &Rectangle) -> bool

Checks if this rect contains the given rect.

pub fn intersects(&self, rect: &Rectangle) -> bool

Checks if this rect intersects with the given rect.

pub fn join_with_rectangle(&mut self, other: &Rectangle)

Joins this rectangle with another one, the result is a rectangle in which the two parents fit.

pub fn join_with_point(&mut self, point: &Point)

Extends this rectangle to cover the given point.

pub fn box_into(&mut self, container: Rectangle)

Box itself inside another rectangle